singer-clojure.parse


catalogclj

(catalog catalog-file)

This function exists as a test seam

This function exists as a test seam
sourceraw docstring

cli-optionsclj

source

configclj

(config config-file)

This function exists as a test seam

This function exists as a test seam
sourceraw docstring

parse-argsclj

(parse-args & args)
source

slurp-jsonclj

(slurp-json f)
(slurp-json f key-fn)
source

stateclj

(state state-file)

This function exists as a test seam and for the post condition

This function exists as a test seam and for the post condition
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries